"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OperationUnit = void 0;
const OperationUnitSource_1 = require("./OperationUnitSource");
/**
 * Operation unit corresponds to a vehicle on a case and it is related to the Assigned Resource values from SOS.
 */
class OperationUnit {
    /**
     *
     * @param unitId The unique id of the unit, corresponds to the Resource Id for Assigned Resource from SOS
     * @param status The current Status, also corresponds to the Status for Assigned Resource from SOS
     * @param role The role of the unit
     * @param source The source of the unit
     * @param eta The estimated time of arrival in epoch milliseconds UTC timezone
     * @param reportedInArea Corresponds to reportedInArea for Assigned Resource from SOS
     */
    constructor(unitId, status, role, source, eta, reportedInArea) {
        this.unitId = unitId;
        this.status = status;
        this.role = role;
        this.source = source;
        this.eta = eta;
        this.reportedInArea = reportedInArea;
    }
    static fromJSON(data) {
        if (data.unitId === undefined) {
            return undefined;
        }
        const source = (data.source === OperationUnitSource_1.OperationUnitSource.CLOUD
            || data.source === OperationUnitSource_1.OperationUnitSource.RAKEL)
            ? data.source : OperationUnitSource_1.OperationUnitSource.UNKNOWN;
        return new OperationUnit(data.unitId, data.status, data.role, data.source, data.eta !== undefined ? new Date(data.eta) : undefined, data.reportedInArea);
    }
}
exports.OperationUnit = OperationUnit;
//# sourceMappingURL=OperationUnit.js.map